coherence.upnp.core.msearch (module) — Cohen3 0.8.0 documentation

# coherence.upnp.core.msearch (module)

## `MSearch`

A class representing a protocol for datagram-oriented transport, e.g. UDP.

class `MSearch`(ssdp_server, test=False)

  Bases: `eventdispatcher.eventdispatcher.EventDispatcher`, `twisted.internet.protocol.DatagramProtocol`, `coherence.log.LogAble`

  Changed in version 0.9.0:

  - Migrated from louie/dispatcher to EventDispatcher

  - The emitted events changed:

    > - UPnP.SSDP.datagram_received => datagram_received

  `logCategory` = 'msearch'
  `datagramReceived`(data, xxx_todo_changeme)

    Called when a datagram is received.

    @param datagram: the string received from the transport. @param addr: tuple of source of datagram.

  `double_discover`()

    Because it’s worth it (with UDP’s reliability)

  `discover`()